Description Usage Arguments Value Examples
Ingest the training dataset and holdout datasets and split the training dataset into train and test.
1 2 3 4 5 6 | ingest_split(
train_test_raw_path = as.character(),
holdout_raw_path = as.character(),
target = as.character(),
prop = as.numeric()
)
|
train_test_raw_path |
Location of the raw train & test csv file to be ingested. |
holdout_raw_path |
Location of the raw holdout csv file to be ingested. |
target |
Name of the target column to be predicted in the datasets. |
prop |
The proportion of train data to model. |
list of data.
train: The tibble for training the model.
test: The tibble for testing the model.
holdout: The tibble of unseen data to predict values for.
1 2 3 4 5 6 7 8 9 | ## Not run:
data_list = ingest_split(
train_test_raw_path="path/to/ingest.csv",
holdout_raw_path="path/to/export.csv",
target="target_col",
prop = 0.8
)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.